"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = loadConfig;

var _fsExtra = _interopRequireDefault(require("fs-extra"));

var _path = _interopRequireDefault(require("path"));

var _jsYaml = _interopRequireDefault(require("js-yaml"));

var _lodash = _interopRequireDefault(require("lodash"));

var log = _interopRequireWildcard(require("./log"));

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj.default = obj; return newObj; } }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

async function loadConfigImpl(filePath) {
  return new Promise(resolve => {
    _fsExtra.default.access(filePath, async err => {
      if (err) {
        log.info(`Can't find the pecorino config file "${filePath}".`);
        resolve({});
      } else {
        log.info(`Pecorino config file is found at "${filePath}".`);
        const configText = await _fsExtra.default.readFile(filePath);

        const configItems = _jsYaml.default.safeLoad(configText);

        resolve(configItems);
      }
    });
  });
}

async function loadConfig(config, overwrite) {
  const fileName = /^(.*)\.([^.]+)$/.exec(config);

  if (!fileName) {
    log.error(`Config filename (${config}) wrong, it should like '[filename].[ext]'. Default is 'pecorino.yaml'.`);
    process.exit(1);
  }

  const nodeEnv = process.env.NODE_ENV || 'development';

  const developmentFileName = _path.default.resolve(process.cwd(), `${fileName[1]}.${nodeEnv}.${fileName[2]}`);

  const defaultFileName = _path.default.resolve(process.cwd(), config);

  const development = await loadConfigImpl(developmentFileName);
  const def = await loadConfigImpl(defaultFileName);

  if (_lodash.default.isEmpty(development) && _lodash.default.isEmpty(def)) {
    log.warn(`Can't find config file "${config}"`);
  }

  return _lodash.default.assign({}, def, development, overwrite);
}