"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.initEnv = initEnv;
exports.register = register;
Object.defineProperty(exports, "loadConfig", {
  enumerable: true,
  get: function () {
    return _config.default;
  }
});
exports.pecorinoLog = void 0;

var _nodeFetch = _interopRequireDefault(require("node-fetch"));

var _config = _interopRequireDefault(require("./config"));

var log = _interopRequireWildcard(require("./log"));

exports.pecorinoLog = log;

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj.default = obj; return newObj; } }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

async function initEnv(configOrFilePath) {
  let settings;

  if (typeof configOrFilePath === 'object') {
    settings = configOrFilePath;
  } else {
    settings = await (0, _config.default)(configOrFilePath || 'pecorino.yaml', {});
  }

  const res = await (0, _nodeFetch.default)(`${settings.master}/conf/${settings.service}`, {
    method: 'GET',
    headers: {
      'Content-Type': 'application/json'
    }
  });

  if (!res.ok) {
    throw new Error(`Assess failed with ${res.status}: ${res.statusText}`);
  }

  const conf = _objectSpread({}, (await res.json()).results, {
    PECORINO_CONFIG_MASTER: settings.master,
    PECORINO_CONFIG_MY_NAME: settings.service,
    PECORINO_CONFIG_MY_IP: settings.ip,
    PECORINO_CONFIG_MY_PORT: settings.port
  });

  process.env = _objectSpread({}, conf, process.env);
  log.info(`Got the configurations from comfit. then starting the service "${settings.service}"...`);
  log.info('Config is: -------------------------------------');
  log.info(JSON.stringify(process.env, null, ' '));
  log.info('------------------------------------------------');
}

async function register(configOrFilePath) {
  let settings;

  if (typeof configOrFilePath === 'object') {
    settings = configOrFilePath;
  } else {
    settings = await (0, _config.default)(configOrFilePath || 'pecorino.yaml', {});
  }

  const res = await (0, _nodeFetch.default)(`${settings.master}/register`, {
    method: 'POST',
    headers: {
      'Content-Type': 'application/json'
    },
    body: JSON.stringify({
      service: settings.service,
      end: `${settings.ip}:${settings.port}`
    })
  });

  if (!res.ok) {
    throw new Error(`Register failed with ${res.status}: ${res.statusText}`);
  }

  const r = await res.json();

  if (r.success) {
    log.info('Register success.');
  } else {
    log.error(`Register service failed with error: ${r.error}`);
  }
}